Index: test/unit/org/openstreetmap/josm/data/osm/WaySegmentTest.java
===================================================================
--- test/unit/org/openstreetmap/josm/data/osm/WaySegmentTest.java	(revision 19064)
+++ test/unit/org/openstreetmap/josm/data/osm/WaySegmentTest.java	(working copy)
@@ -36,6 +36,6 @@
         assertEquals(WaySegment.forNodePair(w, n1, n4).getLowerIndex(), 4);
         assertEquals(WaySegment.forNodePair(w, n4, n1).getLowerIndex(), 5);
         IllegalArgumentException iae = assertThrows(IllegalArgumentException.class, () -> WaySegment.forNodePair(w, n3, n4));
-        assertEquals("The node pair is not consecutive part of the way!", iae.getMessage());
+        assertEquals("Node pair is not a segment of the way!", iae.getMessage());
     }
 }

Index: src/org/openstreetmap/josm/data/osm/IWaySegment.java
===================================================================
--- src/org/openstreetmap/josm/data/osm/IWaySegment.java	(revision 19063)
+++ src/org/openstreetmap/josm/data/osm/IWaySegment.java	(working copy)
@@ -96,7 +96,7 @@
      * @param first first node
      * @param second second node
      * @return way segment
      * @throws IllegalArgumentException if the node pair is not part of way
      */
     public static <N extends INode, W extends IWay<N>> IWaySegment<N, W> forNodePair(W way, N first, N second) {
         int endIndex = way.getNodesCount() - 1;
@@ -107,7 +107,7 @@
             }
             endIndex--;
         }
-        throw new IllegalArgumentException("Node pair is not part of way!");
+        throw new IllegalArgumentException("Node pair is not a segment of the way!");
     }
 
     /**
@@ -96,7 +96,7 @@
      * @param second second node
      * @return way segment
-     * @throws IllegalArgumentException if the node pair is not part of way
+     * @throws IllegalArgumentException if the node pair is a segment of the way
      */
     public static <N extends INode, W extends IWay<N>> IWaySegment<N, W> forNodePair(W way, N first, N second) {
Index: src/org/openstreetmap/josm/data/osm/WaySegment.java
===================================================================
--- src/org/openstreetmap/josm/data/osm/WaySegment.java	(revision 19063)
+++ src/org/openstreetmap/josm/data/osm/WaySegment.java	(working copy)
@@ -25,7 +25,7 @@
      * @param first  first node
      * @param second second node
      * @return way segment
      * @throws IllegalArgumentException if the node pair is not part of way
      */
     public static WaySegment forNodePair(Way way, Node first, Node second) {
         int endIndex = way.getNodesCount() - 1;
@@ -36,7 +36,7 @@
             }
             endIndex--;
         }
-        throw new IllegalArgumentException("The node pair is not consecutive part of the way!");
+        throw new IllegalArgumentException("Node pair is not a segment of the way!");
     }
 
     /**
@@ -25,7 +25,7 @@
      * @param second second node
      * @return way segment
-     * @throws IllegalArgumentException if the node pair is not part of way
+     * @throws IllegalArgumentException if the node pair is a segment of the way
      */
     public static WaySegment forNodePair(Way way, Node first, Node second) {